==> maxdb-source-7_6_00_09.tgz: V76_00_09/MaxDB_ORG/sys/src/SAPDB/SQLManager/Query/Query_NodeDifference.hpp <==
/*!***************************************************************************

  module      : Query_NodeDifference.hpp

  -------------------------------------------------------------------------

  responsible : DirkT

  special area: SQL Manager / Query
  description : 

  last changed: 2004-11-23  16:00
  first created:2004-04-29  10:00

  -------------------------------------------------------------------------

  copyright:    Copyright (c) 2000-2004 SAP AG




    ========== licence begin  GPL
    Copyright (c) 2000-2004 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end



*****************************************************************************/

#ifndef Query_NodeDifference_H
#define Query_NodeDifference_H

// ------------------------------------------------------------------------------------------------

#include "SAPDB/SQLManager/Query/Query_NodeSet.hpp"

// ------------------------------------------------------------------------------------------------

class Query_DifferenceNode : public Query_SetNode
{
protected:    // private copyconstuctor used by CreateDuplicate
    Query_DifferenceNode( const Query_DifferenceNode& N, Query_Node* Father, Query_Quantifier* Q, Query_NodeMapper* mpMap );
public:
    virtual Query_Node* CreateDuplicate( Query_Node* Father, Query_Quantifier* Q, Query_NodeMapper* mpMap );

    Query_DifferenceNode( Query_ManipulationContext& Context, Query_QueryGraph& QueryGraph, Query_Position Position, SyntaxTreeNodeNo APNode, bool All);

    virtual Query_NodeType GetNodeType( void ) { return NT_Difference; }
    virtual void PrintToTrace( Kernel_VTrace& VTrace );

};

// ------------------------------------------------------------------------------------------------

#endif

==> maxdb-source-7_6_00_37.tgz: V76_00_37/MaxDB_ORG/sys/src/SAPDB/SQLManager/Query/Query_NodeDifference.hpp <==
/*!***************************************************************************

    @file     Query_NodeDifference.hpp
    @ingroup  Query
    @author   DirkT
    @brief    
    @see  

  -------------------------------------------------------------------------

  responsible : DirkT

  special area: SQL Manager / Query
  description : 

  last changed: 2005-06-08  12:00
  first created:2004-04-29  10:00

  -------------------------------------------------------------------------

  copyright:    Copyright (c) 2000-2005 SAP AG




    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end




*****************************************************************************/

#ifndef Query_NodeDifference_H
#define Query_NodeDifference_H

// ------------------------------------------------------------------------------------------------

#include "SAPDB/SQLManager/Query/Query_NodeSet.hpp"

// ------------------------------------------------------------------------------------------------
/*!
    @class          Query_DifferenceNode
    @brief          Node that represents a DIFFERENCE
    @copydoc        Query_Node
 */
class Query_DifferenceNode : public Query_SetNode
{
protected:    // private copyconstuctor used by CreateDuplicate
    /*!
        @brief  Protected constructor called by CreateDuplicates
        @param  N       [in]
        @param  Father  [in]
        @param  Q       [in]
        @param  mpMap   [in]
        @param  mpQMap  [in]
    */
    Query_DifferenceNode( const Query_DifferenceNode& N, Query_Node* Father, Query_Quantifier* Q, Query_NodeMapper* mpMap, Query_QuantifierMapper* mpQMap );
public:
    virtual Query_Node* CreateDuplicate( Query_Node* Father, Query_Quantifier* Q, Query_NodeMapper* mpMap, Query_QuantifierMapper* mpQMap );

    /*!
        @brief  Constructor
        @param  Context    [in]
        @param  QueryGraph [in]
        @param  Position   [in]
        @param  APNode     [in]
        @param  All        [in]
    */    
    Query_DifferenceNode( Query_ManipulationContext& Context, Query_QueryGraph& QueryGraph, Query_Position Position, SyntaxTreeNodeNo APNode, bool All);

    virtual NodeType GetNodeType( void ) { return Difference; }
    virtual void PrintToTrace( Kernel_VTrace& VTrace );

    virtual Query_Position PositionForParse( void ) { return P_Difference; }
};

// ------------------------------------------------------------------------------------------------

#endif
